@@ -9,18 +9,17 @@ function(x, values, int=FALSE) {
   nx <- names(x)
   x <- as.vector(x)
 #
-  # TRANSFORM INTO A FACTOR AND DEFINE LEVELS
-  x <- round(x,0)
+  # DEFINE LEVELS AND TRANSFORM INTO A FACTOR
   levels <- if(!missing(values)) values else sort(unique(x))
-  x <- factor(x,levels=levels)
-#
-  # IF INTERCEPT IS NOT REQUIRED, DROP THE FIRST LEVEL
-  if(length(levels)>1L) {
-    if(!int) levels <- levels[-1L]
-  } else int <- TRUE
+  xfac <- factor(x,levels=levels)
 #
   # TRANSFORMATION
-  basis <- as.matrix(outer(x,levels,"==")+0L)
+  basis <- as.matrix(outer(xfac,levels,"==")+0L)
+#
+  # IF INTERCEPT IS NOT REQUIRED, DROP THE FIRST COLUMN
+  if(ncol(basis)>1L) {
+    if(!int) basis <- basis[,-1L,drop=FALSE]
+  } else int <- TRUE
 #
   # NAMES AND ATTRIBUTES
   dimnames(basis) <- list(nx,seq(ncol(basis)))
